#include <pcl/io/pcd_io.h>

#include "velodyne_pointcloud\point_types.h"
#include <iostream>
#include <fstream>

using namespace std;

void savePTXFile(const std::string &file_name, const pcl::PointCloud<velodyne_pointcloud::PointXYZIR> &cloud)
{
	ofstream outs;
	outs.open(file_name);

	outs << cloud.height << std::endl;
	outs << cloud.width << std::endl;
	outs << "0 0 0" << std::endl;
	outs << "1 0 0" << std::endl;
	outs << "0 1 0" << std::endl;
	outs << "0 0 1" << std::endl;
	outs << "1 0 0 0" << std::endl;
	outs << "0 1 0 0" << std::endl;
	outs << "0 0 1 0" << std::endl;
	outs << "0 0 0 1" << std::endl;


	for (int i = 0; i < cloud.height; ++i){
		for (int j = cloud.width - 1; j >= 0; --j){
			int n = i*cloud.width + j;
			outs << cloud.points[n].z << " " << cloud.points[n].x << " " << cloud.points[n].y << " " << (int)cloud.points[n].intensity << " 0 0 0" << std::endl;
		}
	}

	outs.close();
}

int
main(int argc, char** argv)
{
	pcl::PointCloud<velodyne_pointcloud::PointXYZIR> cloud;
	
	if (argc != 2) {
		std::cout << "Usage: pcd2ptxrgb.exe filename.pcd" << std::endl;
		exit(-1);
	}

	pcl::io::loadPCDFile(argv[1], cloud);

	string ptx = argv[1];
	ptx.replace(ptx.find(".pcd"), 4, ".ptx");
	savePTXFile(ptx, cloud);

	return 0;
}


